[![Build Status](https://travis-ci.org/abra-eyetracking/abra-eyetracking.svg?branch=master)](https://travis-ci.org/abra-eyetracking/abra-eyetracking)
## Abra Eye-tracking. ver.1.0
Abra is an open-source python eye tracking data analysis tool which provides a simple interface for managing .edf files generated by EyeLink eye trackers.

#### Installation
Python 3:
`pip install abra`
